@@ -2,23 +2,19 @@
 
 ################################################################################
 ###                                                                          ###
-### Created by Martin Genet, 2016-2021                                       ###
+### Created by Martin Genet, 2016-2022                                       ###
 ###                                                                          ###
 ### École Polytechnique, Palaiseau, France                                   ###
 ###                                                                          ###
 ################################################################################
 
-from builtins import range
-
 import dolfin
 import glob
 import numpy
 import os
-import time
 import vtk
 
 import myPythonLibrary    as mypy
-import myVTKPythonLibrary as myvtk
 
 import dolfin_warp as dwarp
 
@@ -37,18 +33,19 @@ class ImageIterator():
         self.printer = self.problem.printer
         self.solver  = solver
 
-        self.working_folder           = parameters["working_folder"]           if ("working_folder"           in parameters) else "."
-        self.working_basename         = parameters["working_basename"]         if ("working_basename"         in parameters) else "sol"
-        self.register_ref_frame       = parameters["register_ref_frame"]       if ("register_ref_frame"       in parameters) else False
-        self.initialize_U_from_file   = parameters["initialize_U_from_file"]   if ("initialize_U_from_file"   in parameters) else False
-        self.initialize_U_folder      = parameters["initialize_U_folder"]      if ("initialize_U_folder"      in parameters) else "."
-        self.initialize_U_basename    = parameters["initialize_U_basename"]    if ("initialize_U_basename"    in parameters) else None
-        self.initialize_U_ext         = parameters["initialize_U_ext"]         if ("initialize_U_ext"         in parameters) else "vtu"
-        self.initialize_U_array_name  = parameters["initialize_U_array_name"]  if ("initialize_U_array_name"  in parameters) else "displacement"
-        self.initialize_DU_with_DUold = parameters["initialize_DU_with_DUold"] if ("initialize_DU_with_DUold" in parameters) else False
-        self.write_VTU_file           = parameters["write_VTU_file"]           if ("write_VTU_file"           in parameters) else True
-        self.write_XML_file           = parameters["write_XML_file"]           if ("write_XML_file"           in parameters) else False
-        self.iteration_mode           = parameters["iteration_mode"]           if ("iteration_mode"           in parameters) else "normal" # MG20200616: This should be a bool
+        self.working_folder               = parameters.get("working_folder"              , "."           )
+        self.working_basename             = parameters.get("working_basename"            , "sol"         )
+        self.register_ref_frame           = parameters.get("register_ref_frame"          , False         )
+        self.initialize_U_from_file       = parameters.get("initialize_U_from_file"      , False         )
+        self.initialize_U_folder          = parameters.get("initialize_U_folder"         , "."           )
+        self.initialize_U_basename        = parameters.get("initialize_U_basename"       , "init"        )
+        self.initialize_U_ext             = parameters.get("initialize_U_ext"            , "vtu"         )
+        self.initialize_U_array_name      = parameters.get("initialize_U_array_name"     , "displacement")
+        self.initialize_DU_with_DUold     = parameters.get("initialize_DU_with_DUold"    , False         )
+        self.write_qois_limited_precision = parameters.get("write_qois_limited_precision", False         )
+        self.write_VTU_file               = parameters.get("write_VTU_file"              , True          )
+        self.write_XML_file               = parameters.get("write_XML_file"              , False         )
+        self.iteration_mode               = parameters.get("iteration_mode"              , "normal"      ) # MG20200616: This should be a bool
 
 
 
@@ -67,7 +64,8 @@ class ImageIterator():
         qoi_filebasename = self.working_folder+"/"+self.working_basename+"-qoi"
         qoi_printer = mypy.DataPrinter(
             names=qoi_names,
-            filename=qoi_filebasename+".dat")
+            filename=qoi_filebasename+".dat",
+            limited_precision=self.write_qois_limited_precision)
 
         if not (self.register_ref_frame):
             self.printer.dec()
@@ -114,11 +112,11 @@ class ImageIterator():
         self.printer.print_str("Looping over frames…")
 
         if (self.initialize_U_from_file):
-            mesh_series = dwarp.MeshSeries(
-                problem=self.problem,
+            meshes_series = dwarp.MeshesSeries(
                 folder=self.initialize_U_folder,
                 basename=self.initialize_U_basename,
-                ext=self.initialize_U_ext)
+                ext=self.initialize_U_ext,
+                printer=self.problem.printer)
 
             dof_to_vertex_map = dolfin.dof_to_vertex_map(self.problem.U_fs)
 
@@ -163,7 +161,8 @@ class ImageIterator():
                 self.printer.print_var("k_frame",k_frame,-1)
 
                 if (self.initialize_U_from_file):
-                    mesh = mesh_series.get_mesh(k_frame)
+                    self.printer.print_str("Initializing displacement…")
+                    mesh = meshes_series.get_mesh(k_frame=k_frame)
                     array_U = mesh.GetPointData().GetArray(self.initialize_U_array_name)
                     array_U = vtk.util.numpy_support.vtk_to_numpy(array_U)[:,:self.problem.mesh_dimension]
                     # print(array_U)
@@ -172,6 +171,7 @@ class ImageIterator():
                     array_U = numpy.reshape(array_U, array_U.size)
                     # print(array_U)
                     self.problem.U.vector()[:] = array_U[dof_to_vertex_map]
+                    self.problem.U_norm = self.problem.U.vector().norm("l2")
 
                 elif (self.initialize_DU_with_DUold):
                     self.problem.U.vector().axpy(1., self.problem.DUold.vector())
