@@ -2,23 +2,18 @@
 
 ################################################################################
 ###                                                                          ###
-### Created by Ezgi Berberoğlu, 2018-2021                                    ###
+### Created by Ezgi Berberoğlu, 2017-2021                                    ###
 ###                                                                          ###
 ### Swiss Federal Institute of Technology (ETH), Zurich, Switzerland         ###
+### École Polytechnique, Palaiseau, France                                   ###
 ###                                                                          ###
-### And Martin Genet, 2016-2019                                              ###
+### And Martin Genet, 2016-2022                                              ###
 ###                                                                          ###
 ### École Polytechnique, Palaiseau, France                                   ###
 ###                                                                          ###
 ################################################################################
 
 import dolfin
-import numpy
-
-import myPythonLibrary    as mypy
-import myVTKPythonLibrary as myvtk
-
-import dolfin_warp as dwarp
 
 ################################################################################
 
