@@ -2,24 +2,14 @@
 
 ################################################################################
 ###                                                                          ###
-### Created by Martin Genet, 2016-2021                                       ###
+### Created by Martin Genet, 2016-2022                                       ###
 ###                                                                          ###
 ### École Polytechnique, Palaiseau, France                                   ###
 ###                                                                          ###
 ################################################################################
 
-import dolfin
-import glob
 import math
 import numpy
-import os
-import random
-import vtk
-
-import myPythonLibrary    as mypy
-import myVTKPythonLibrary as myvtk
-
-import dolfin_warp as dwarp
 
 ################################################################################
 
@@ -55,7 +45,7 @@ class Mapping():
             self.X = self.X_homogeneous
             self.x = self.x_homogeneous
         elif (self.deformation["type"] == "heart"):
-            assert (structure["type"] == "heart"), "structure type must be \"heart\" for \"heart\" type deformation. Aborting."
+            assert (structure["type"] == "heart"), "structure type must be \"heart\" for \"heart\" type deformation, not \""+str(structure["type"])+"\". Aborting."
             self.init_t = self.init_t_heart
             self.X = self.X_heart
             self.x = self.x_heart
@@ -68,7 +58,7 @@ class Mapping():
             self.Re = structure["Re"]
             self.R = numpy.empty((3,3))
         else:
-            assert (0), "deformation type must be \"no\", \"translation\", \"rotation\", \"homogeneous\" or \"heart\". Aborting."
+            assert (0), "deformation type must be \"no\", \"translation\", \"rotation\", \"homogeneous\" or \"heart\", not \""+str(self.deformation["type"])+"\". Aborting."
 
         if (evolution["type"] == "linear"):
             self.phi = self.phi_linear
@@ -76,7 +66,7 @@ class Mapping():
             self.phi = self.phi_sine
             self.T = evolution["T"]
         else:
-            assert (0), "evolution ("+evolution["type"]+") type must be \"linear\" or \"sine\". Aborting."
+            assert (0), "evolution type must be \"linear\" or \"sine\", not \""+str(evolution["type"])+"\". Aborting."
 
     def phi_linear(self, t):
         return t
@@ -137,7 +127,7 @@ class Mapping():
             Fxz = self.deformation["Fxz"] if ("Fxz" in self.deformation) else 0.
             self.F = numpy.eye(3) + (numpy.array([[Fxx, Fxy, Fxz],
                                                   [Fyx, Fyy, Fyz],
-                                                  [Fzx, Fzy, Fzz]])-numpy.eye(3))*self.phi(t)
+                                                  [Fzx, Fzy, Fzz]]) - numpy.eye(3))*self.phi(t)
         self.Finv = numpy.linalg.inv(self.F)
 
     def init_t_heart(self, t):
