@@ -2,7 +2,7 @@
 
 ################################################################################
 ###                                                                          ###
-### Created by Martin Genet, 2016-2021                                       ###
+### Created by Martin Genet, 2016-2022                                       ###
 ###                                                                          ###
 ### École Polytechnique, Palaiseau, France                                   ###
 ###                                                                          ###
@@ -12,16 +12,10 @@
 ###                                                                          ###
 ################################################################################
 
-from builtins import range
-
 import dolfin
-import glob
 import numpy
 import vtk
 
-import myPythonLibrary    as mypy
-import myVTKPythonLibrary as myvtk
-
 import dolfin_warp as dwarp
 
 ################################################################################
