@@ -2,7 +2,7 @@
 
 ################################################################################
 ###                                                                          ###
-### Created by Martin Genet, 2016-2021                                       ###
+### Created by Martin Genet, 2016-2022                                       ###
 ###                                                                          ###
 ### École Polytechnique, Palaiseau, France                                   ###
 ###                                                                          ###
@@ -12,23 +12,18 @@ import dolfin
 import os
 import shutil
 
-import myPythonLibrary    as mypy
-import myVTKPythonLibrary as myvtk
-
-import dolfin_warp as dwarp
-
 ################################################################################
 
 def write_VTU_file(
         filebasename,
         function,
-        time,
+        time=None,
         zfill=3):
 
     file_pvd = dolfin.File(filebasename+"__.pvd")
-    file_pvd << (function, float(time))
+    file_pvd << (function, float(time) if (time is not None) else 0.)
     os.remove(
         filebasename+"__.pvd")
     shutil.move(
         filebasename+"__"+"".zfill(6)+".vtu",
-        filebasename+"_"+str(time).zfill(zfill)+".vtu")
+        filebasename+("_"+str(time).zfill(zfill) if (time is not None) else "")+".vtu")
